@@ -1,6 +1,9 @@
 //! This is a collection of string metrics that are suitable for use with a
 //! BK-tree.
 
+#[cfg(feature = "serde")]
+extern crate serde;
+
 use Metric;
 
 extern crate triple_accel;
@@ -23,11 +26,10 @@ use self::triple_accel::{levenshtein, levenshtein::levenshtein_simd_k};
 ///
 /// [1]: https://en.wikipedia.org/wiki/Levenshtein_distance
 /// [2]: https://en.wikipedia.org/wiki/Wagner%E2%80%93Fischer_algorithm
-#[derive(Debug)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Levenshtein;
 
-impl<K: AsRef<str> + ?Sized> Metric<K> for Levenshtein
-{
+impl<K: AsRef<str> + ?Sized> Metric<K> for Levenshtein {
     fn distance(&self, a: &K, b: &K) -> u32 {
         let a_bytes = a.as_ref().as_bytes();
         let b_bytes = b.as_ref().as_bytes();
